==> kubernetes-model-1.1.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/DeploymentStatusFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface DeploymentStatusFluent<A extends DeploymentStatusFluent<A>> extends Fluent<A>{


    public Integer getAvailableReplicas();
    public A withAvailableReplicas(Integer availableReplicas);
    public Boolean hasAvailableReplicas();
    public A addToConditions(int index,DeploymentCondition item);
    public A setToConditions(int index,DeploymentCondition item);
    public A addToConditions(DeploymentCondition... items);
    public A addAllToConditions(Collection<DeploymentCondition> items);
    public A removeFromConditions(DeploymentCondition... items);
    public A removeAllFromConditions(Collection<DeploymentCondition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 */
@Deprecated public List<DeploymentCondition> getConditions();
    public List<DeploymentCondition> buildConditions();
    public DeploymentCondition buildCondition(int index);
    public DeploymentCondition buildFirstCondition();
    public DeploymentCondition buildLastCondition();
    public DeploymentCondition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<DeploymentConditionBuilder> predicate);
    public A withConditions(List<DeploymentCondition> conditions);
    public A withConditions(DeploymentCondition... conditions);
    public Boolean hasConditions();
    public DeploymentStatusFluent.ConditionsNested<A> addNewCondition();
    public DeploymentStatusFluent.ConditionsNested<A> addNewConditionLike(DeploymentCondition item);
    public DeploymentStatusFluent.ConditionsNested<A> setNewConditionLike(int index,DeploymentCondition item);
    public DeploymentStatusFluent.ConditionsNested<A> editCondition(int index);
    public DeploymentStatusFluent.ConditionsNested<A> editFirstCondition();
    public DeploymentStatusFluent.ConditionsNested<A> editLastCondition();
    public DeploymentStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<DeploymentConditionBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public Integer getReplicas();
    public A withReplicas(Integer replicas);
    public Boolean hasReplicas();
    public Integer getUnavailableReplicas();
    public A withUnavailableReplicas(Integer unavailableReplicas);
    public Boolean hasUnavailableReplicas();
    public Integer getUpdatedReplicas();
    public A withUpdatedReplicas(Integer updatedReplicas);
    public Boolean hasUpdatedReplicas();

    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DeploymentConditionFluent<DeploymentStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}

==> kubernetes-model-2.0.4-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/DeploymentStatusFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface DeploymentStatusFluent<A extends DeploymentStatusFluent<A>> extends Fluent<A>{


    public Integer getAvailableReplicas();
    public A withAvailableReplicas(Integer availableReplicas);
    public Boolean hasAvailableReplicas();
    public Long getCollisionCount();
    public A withCollisionCount(Long collisionCount);
    public Boolean hasCollisionCount();
    public A addToConditions(int index,DeploymentCondition item);
    public A setToConditions(int index,DeploymentCondition item);
    public A addToConditions(DeploymentCondition... items);
    public A addAllToConditions(Collection<DeploymentCondition> items);
    public A removeFromConditions(DeploymentCondition... items);
    public A removeAllFromConditions(Collection<DeploymentCondition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 */
@Deprecated public List<DeploymentCondition> getConditions();
    public List<DeploymentCondition> buildConditions();
    public DeploymentCondition buildCondition(int index);
    public DeploymentCondition buildFirstCondition();
    public DeploymentCondition buildLastCondition();
    public DeploymentCondition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<DeploymentConditionBuilder> predicate);
    public A withConditions(List<DeploymentCondition> conditions);
    public A withConditions(DeploymentCondition... conditions);
    public Boolean hasConditions();
    public DeploymentStatusFluent.ConditionsNested<A> addNewCondition();
    public DeploymentStatusFluent.ConditionsNested<A> addNewConditionLike(DeploymentCondition item);
    public DeploymentStatusFluent.ConditionsNested<A> setNewConditionLike(int index,DeploymentCondition item);
    public DeploymentStatusFluent.ConditionsNested<A> editCondition(int index);
    public DeploymentStatusFluent.ConditionsNested<A> editFirstCondition();
    public DeploymentStatusFluent.ConditionsNested<A> editLastCondition();
    public DeploymentStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<DeploymentConditionBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public Integer getReadyReplicas();
    public A withReadyReplicas(Integer readyReplicas);
    public Boolean hasReadyReplicas();
    public Integer getReplicas();
    public A withReplicas(Integer replicas);
    public Boolean hasReplicas();
    public Integer getUnavailableReplicas();
    public A withUnavailableReplicas(Integer unavailableReplicas);
    public Boolean hasUnavailableReplicas();
    public Integer getUpdatedReplicas();
    public A withUpdatedReplicas(Integer updatedReplicas);
    public Boolean hasUpdatedReplicas();

    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DeploymentConditionFluent<DeploymentStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}
